@@ -23,7 +23,7 @@ class RuntimeConfig(lime_admin.plugins.AdminPlugin):
     def title(self):
         """The title of the plugin
         """
-        return 'Scrive integration for lime'
+        return 'Scrive eSigning'
 
     @property
     def version(self):
